from setuptools import setup, find_packages


setup(
    name="sqmanage",
    version="0.1.0",
    description="Gestor de sqlite",
    author="Josue Santos",
    author_email="santosarias502@gmail.com",
    packages=find_packages(),
)
